@@ -55,7 +55,7 @@ protected Q_SLOTS:
     virtual void onCancelled();
     virtual void onError(const QString &message, const QString &details, int errorCode);
     virtual void onInfo(const QString &info);
-    virtual void onEntry(Archive::Entry *entry);
+    virtual void onEntry(Kerfuffle::Archive::Entry *entry);
     virtual void onProgress(double progress);
     virtual void onEntryRemoved(const QString &path);
     virtual void onFinished(bool result);
@@ -63,12 +63,12 @@ protected Q_SLOTS:
 
 Q_SIGNALS:
     void entryRemoved(const QString &entry);
-    void newEntry(Archive::Entry *);
+    void newEntry(Kerfuffle::Archive::Entry *);
     void userQuery(Kerfuffle::Query *);
 
 private:
-    Archive *m_archive;
-    ReadOnlyArchiveInterface *m_archiveInterface;
+    Archive *m_archive = nullptr;
+    ReadOnlyArchiveInterface *m_archiveInterface = nullptr;
     QElapsedTimer jobTimer;
 
     class Private;
@@ -123,7 +123,7 @@ private:
     qlonglong m_filesCount;
 
 private Q_SLOTS:
-    void onNewEntry(const Archive::Entry *);
+    void onNewEntry(const Kerfuffle::Archive::Entry *);
 };
 
 /**
@@ -153,13 +153,16 @@ private:
     /**
      * Tracks whether the job is loading or extracting the archive.
      */
-    enum Step { Loading, Extracting };
+    enum Step {
+        Loading,
+        Extracting
+    };
 
     void setupDestination();
 
     Step m_step = Loading;
     ExtractJob *m_extractJob = nullptr;
-    LoadJob *m_loadJob;
+    LoadJob *m_loadJob = nullptr;
     QString m_destination;
     bool m_autoSubfolder;
     bool m_preservePaths;
@@ -253,8 +256,8 @@ public Q_SLOTS:
 private:
     QString extractionDir() const;
 
-    Archive::Entry *m_entry;
-    QTemporaryDir *m_tmpExtractDir;
+    Archive::Entry *m_entry = nullptr;
+    QTemporaryDir *m_tmpExtractDir = nullptr;
     bool m_passwordProtectedHint;
 };
 
@@ -330,7 +333,7 @@ protected Q_SLOTS:
 private:
     int m_finishedSignalsCount;
     const QList<Archive::Entry *> m_entries;
-    Archive::Entry *m_destination;
+    Archive::Entry *m_destination = nullptr;
     CompressionOptions m_options;
 };
 
